@@ -4,7 +4,7 @@ use strict;
 
 # ABSTRACT: Mock the world with one object
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 our $AUTOLOAD;
 
@@ -98,7 +98,7 @@ Test::Mock::One - Mock the world with one object
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -155,15 +155,13 @@ Tell us how to stringify the object
 
 =back
 
-=back
-
 =head2 isa
 
 Override the ISA from the object
 
 =head1 AUTHOR
 
-Wesley Schwengle <wesleys@opperschaap.net>
+Wesley Schwengle <waterkip@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
